@@ -3,9 +3,14 @@
 from .google_trans import GoogleTranslator
 from .pons import PonsTranslator
 from .linguee import LingueeTranslator
+from .mymemory import MyMemoryTranslator
+
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
-__all__ = [GoogleTranslator, PonsTranslator, LingueeTranslator]
+__all__ = [GoogleTranslator,
+           PonsTranslator,
+           LingueeTranslator,
+           MyMemoryTranslator]
